#
# spec file for package libibumad
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define umad_so 3
%define git_id -gitecda3a5

Name:           libibumad
Summary:        User MAD library functions for Infiniband diagnostic and management tools
License:        GPL-2.0 or BSD-2-Clause
Group:          Productivity/Networking/System
Version:        1.3.10.2
Release:        2.5
Source0:        %{name}-%{version}%{git_id}.tar.xz
Source1:        baselibs.conf
Url:            http://www.openfabrics.org
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  libtool

%description
libibumad provides the user MAD library functions which sit on top of
the user MAD modules in the kernel. These are used by the IB diagnostic
and management tools, including OpenSM

%package     -n %{name}%{umad_so}
Summary:        Runtime User MAD library
License:        GPL-2.0 or BSD-2-Clause
Group:          System/Libraries
Url:            http://www.openfabrics.org
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description -n %{name}%{umad_so}
This package contains the User MAD runtime library.

%package        devel
Summary:        Development files for the libibumad library
License:        GPL-2.0 or BSD-2-Clause
Group:          Development/Libraries/C and C++
Requires:       %{name}%{umad_so} = %{version}

%description    devel
Development files for the libibumad library.

%package        devel-static
Summary:        The static libibumad library
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
Requires:       libibumad-devel = %{version}

%description    devel-static
This package contains the static libibumad library.


%prep
%setup -q
./autogen.sh

%build
%configure --enable-static
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install
rm -f "%buildroot/%_libdir"/*.la

%post -n %{name}%{umad_so} -p /sbin/ldconfig

%postun -n %{name}%{umad_so} -p /sbin/ldconfig

%files -n %{name}%{umad_so}
%defattr(-,root,root)
%doc AUTHORS COPYING ChangeLog
%_libdir/libibumad.so.*
%_mandir/man3/*

%files devel
%defattr(-,root,root)
%dir %_includedir/infiniband
%_includedir/infiniband/*.h
%_libdir/libibumad.so

%files devel-static
%defattr(-,root,root)
%_libdir/libibumad.a

%changelog
* Tue Mar 22 2016 ndas@suse.de
- Add reference to fate#320600
* Wed Feb 24 2016 pth@suse.de
- Update to 1.3.10.2 from git repo as ibasm needs it (fate#319228)
  For changes see included ChangeLog.
- Add baselibs.conf and tag as source.
* Tue Jun  3 2014 pth@suse.de
- Update to OFED 3.12 final.
* Thu Feb 13 2014 pth@suse.de
- Update to 1.3.9 for fate#315488:
  * update shared library version
  * document the setting of errno for umad_send and umad_recv
  * update umad_[send|recv] man pages to document how rmpp is handled
  * umad.c: In resolve_ca_port, skip ethernet link layer ports
  * Fix memory leak in resolve_ca_port
  * fix umad_register man page
* Wed Jan 29 2014 pth@suse.de
- License is GPL-2.0 not GPL-2.0+
* Fri Jan 17 2014 pth@suse.de
- Update to 1.3.8 from OFED 3.12.
* Mon Sep 24 2012 pth@suse.de
- Fix file lists
- move defattr to the top of the file list
* Thu Sep 13 2012 pth@suse.de
- Fix chronological order of the changes.
* Mon Sep 10 2012 pth@suse.de
- Do build and package static libraries.
* Wed Sep  5 2012 jengelh@inai.de
- Remove redundant sections from specfile, set SRPM group
- Parallel build with %%_smp_mflags
- Cease shipping static libraries
* Fri Aug 31 2012 pth@suse.de
- Update to 1.3.7 from OFED 1.5.4.1.
* Tue May  8 2012 pth@suse.de
- BuildRequire automake, autoconf and libtool.
* Thu Dec 16 2010 pth@suse.de
- Move static library into its own subpackage.
* Tue Dec 14 2010 pth@suse.de
- Fix source0 mentioned twice.
* Thu Dec  9 2010 pth@suse.de
- Shorten summary and fix typo in -devel package group.
* Fri Oct 29 2010 pth@suse.de
- Generate new subpackage libibumad<so_version> and adapt
  dependencies.
- Adapt post and postun.
* Fri Oct 22 2010 stefan.fent@novell.com
- update to 1.3.6 from OFED 1.5.2
* Tue May 25 2010 jjolly@novell.com
- Also removed static package dependency on libibcommon
* Mon May 24 2010 jjolly@novell.com
- Updated to v1.3.4 from OFED 1.5.1
- Removed dependency on libibcommon and libibverbs.
* Mon Feb 22 2010 jjolly@suse.de
- Update to v1.2.3_20090314 from OFED 1.4.2
* Wed Oct 15 2008 jjolly@suse.de
- Update to version from OFED 1.3.1 release
* Thu Feb 28 2008 jjolly@suse.de
- Updated to 1.1.7 from OFED 1.3 GA release
* Tue Jan 29 2008 jjolly@suse.de
- Updated to 1.1.6 from OFED 1.3 rc2 release
* Mon Jul  2 2007 hvogel@suse.de
- use correct version 1.0.5 that comes with OFED 1.2
* Wed Jun 20 2007 hvogel@suse.de
- Initial Package, Version 1.0.0
